#
# spec file for package stockfish
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


# See evaluate.h > EvalFileDefaultName
%define nnuenetS nn-37f18f62d772.nnue
%define nnuenetB nn-1111cefa1111.nnue
Name:           stockfish
Version:        17
Release:        1.3
Summary:        Chess engine
License:        GPL-3.0-or-later
URL:            https://stockfishchess.org
Source0:        https://github.com/official-stockfish/Stockfish/archive/sf_%{version}.tar.gz#/Stockfish-sf_%{version}.tar.gz
Source1:        https://tests.stockfishchess.org/api/nn/%{nnuenetS}
Source2:        https://tests.stockfishchess.org/api/nn/%{nnuenetB}
# steal some documentation from ubuntu
Source10:       %{name}-interface.txt
Source11:       %{name}.6-20091204230329-yljoyxocuxhxg1ot-76/%{name}.6
# If 'Version' is not set it will display the date as version number. We dont want __DATE__ and Version is set anyways.
Patch0:         date.patch
# Don't try to download file. We already have it.
Patch1:         stockfish-remove-net.patch
BuildRequires:  dos2unix
BuildRequires:  gcc-c++
BuildRequires:  xz
Recommends:     xboard
Provides:       chess_backend
ExclusiveArch:  %{power64} %{ix86} x86_64 armv7l armv7hl armv7hnl
%ifarch %{power64}
BuildRequires:  gcc-c++-32bit
%endif

%description
Stockfish is a UCI chess engine derived from Glaurung 2.1. It is not a
complete chess program, but requires some UCI compatible GUI (like XBoard with
PolyGlot, eboard, Arena, Sigma Chess, Shredder, Chess Partner or Fritz) in
order to be used comfortably. Read the documentation for your GUI of choice for
information about how to use Stockfish with your GUI.

%prep
%autosetup -p1 -n Stockfish-sf_%{version}
cp %{SOURCE1} src/
cp %{SOURCE2} src/
cp -p %{SOURCE10} %{SOURCE11} .

dos2unix %{name}-interface.txt
dos2unix Copying.txt

%build
cd src
%ifarch x86_64
make %{?_smp_mflags} build ARCH=x86-64
%else
%ifarch %{power_64}
make %{?_smp_mflags} build ARCH=ppc-64
%else
%ifarch armv7l armv7hl armv7hnl
make %{?_smp_mflags} build ARCH=armv7
%else
#ix86
make %{?_smp_mflags} build ARCH=general-32
%endif
%endif
%endif

%install
mkdir -p %{buildroot}%{_bindir}
install -m 755 -p src/%{name} %{buildroot}%{_bindir}
mkdir -p %{buildroot}%{_mandir}/man6
cp -p %{name}.6 %{buildroot}%{_mandir}/man6

%files
%license Copying.txt
%doc AUTHORS %{name}-interface.txt README.md
%{_mandir}/man*/%{name}.*
%{_bindir}/%{name}

%changelog
* Mon Sep  9 2024 Michael Vetter <mvetter@suse.com>
- Update to 17:
  * Improved engine lines
    This release introduces principal variations (PVs) that are more
    informative for mate and decisive table base (TB) scores. In both
    cases, the PV will contain all moves up to checkmate. For mate scores,
    the PV shown is the best variation known to the engine at that point,
    while for table base wins, it follows, based on the TB, a sequence of
    moves that preserves the game outcome to checkmate.
  * NUMA performance optimization
    For high-end computers with multiple CPUs (typically a dual-socket
    architecture with 100+ cores), this release automatically improves
    performance with a NumaPolicy setting that optimizes non-uniform memory
    access (NUMA). Although typical consumer hardware will not benefit,
    speedups of up to 2.8x have been measured.
- Update date.pach, stockfish-remove-net.patch
* Mon Feb 26 2024 Michael Vetter <mvetter@suse.com>
- Update to 16.1:
  * In our testing against its predecessor, Stockfish 16.1 shows a
    notable improvement in performance, with an Elo gain of up to
    27 points and winning over 2 times more game pairs than it loses.
  * Updated neural network architecture: The neural network architecture
    has undergone two updates and is currently in its 8th version.
  * Removal of handcrafted evaluation (HCE): This release marks the
    removal of the traditional handcrafted evaluation and the transition
    to a fully neural network-based approach.
  * Dual NNUE: For the first time, Stockfish includes a secondary neural
    network, used to quickly evaluate positions that are easily decided.
  * Use NNUE and UCI_AnalyseMode have been removed as they no longer had
    any effect. SlowMover has also been removed in favor of Move Overhead.
- Use %%autosetup macro. Allows to eliminate the usage of deprecated PatchN.
* Tue Dec  6 2022 Michael Vetter <mvetter@suse.com>
- Update to 15.1:
  * Elo gain and competition results:
    With this release, version 5 of the NNUE neural net architecture
    has been introduced, and the training data has been extended to
    include Fischer random chess (FRC) positions. As a result, Elo
    gains are largest for FRC, reaching up to 50 Elo for doubly
    randomized FRC (DFRC). More importantly, also for standard chess
    this release progressed and will win two times more game pairs than
    it loses against Stockfish 15.
  * New evaluation:
    This release also introduces a new convention for the evaluation
    that is reported by search. An evaluation of +1 is now no longer
    tied to the value of one pawn, but to the likelihood of winning the
    game. With a +1 evaluation, Stockfish has now a 50%% chance of winning
    the game against an equally strong opponent. This convention scales
    down evaluations a bit compared to Stockfish 15 and allows for
    consistent evaluations in the future.
- Refresh:
  * date.patch
  * stockfish-remove-net.patch
- Remove nn-6877cd24400e.nnue
- Add nn-ad9b42354671.nnue
- Keep man page and stockfish-interface.txt but remove URL from
  Source. Because not available anymore.
* Wed Apr 20 2022 Michael Vetter <mvetter@suse.com>
- Update to 15:
  Stockfish 15 continues to push the boundaries of chess, providing
  unrivalled analysis and playing strength. In our testing, Stockfish
  15 is ahead of Stockfish 14 by 36 Elo points and wins nine times
  more game pairs than it loses.
- Add stockfish-remove-net.patch: Don't try to donwload nnue
  we already have it.
* Sun Mar 27 2022 Dirk Müller <dmueller@suse.com>
- update to 14.1:
  Compared to Stockfish 14, this release introduces a more advanced NNUE
  architecture and various search improvements. In self play testing, using a
  book of balanced openings, Stockfish 14.1 wins three times more game pairs than
  it loses. At this high level, draws are very common, so the Elo difference to
  Stockfish 14 is about 17 Elo
* Fri Jul  9 2021 Stephan Kulow <coolo@suse.com>
- Update to version 14:
  The engine is now significantly stronger than just a few months
  ago, and wins four times more game pairs than it loses against
  the previous release version.
  Stockfish 14 is now at least 400 Elo ahead of Stockfish 7, a
  top engine in 2016. During the last five years, Stockfish has thus
  gained about 80 Elo per year.
- Refresh date.patch
* Thu Apr 29 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to version 13:
  * Significantly stronger than any of its predecessors:
    Stockfish 13 outperforms Stockfish 12 by at least 35 Elo
  * When playing against a one-year-old Stockfish, it wins 60 times
    more game pairs than it loses
  * An NNUE network retrained on billions of positions
  * Much faster network evaluation code
  * Significantly improved search heuristics
  * Additional evaluation tweaks
- Drop update-nnue.patch in favor of the release one
- Use SourceUrl for nnue
* Fri Oct  9 2020 dsterba@suse.cz
- Update to version 12:
  * 130 Elo stronger than version 11
  * powered by NNUE (nn-baeb9ef2d183.nnue)
  * More at https://github.com/official-stockfish/Stockfish/commit/c306d838697011da0a960758dde3f7ede6849060
  * Added patch: update-nnue.patch
* Mon Jan 20 2020 Michael Vetter <mvetter@suse.com>
- Update to version 11:
  * 50 Elo stronger than the last version
  * For detail see:
  https://github.com/official-stockfish/Stockfish/commit/c3483fa9a7d7c0ffa9fcc32b467ca844cfb63790
* Tue Dec 11 2018 Jan Engelhardt <jengelh@inai.de>
- Trim redundant wording.
* Fri Nov 30 2018 mvetter@suse.com
- Update to version 10
  * Upstream does not provide a change log. Please see the git
    history at https://github.com/official-stockfish/Stockfish/
    for more details.
* Mon Jul 16 2018 msuchanek@suse.com
- gcc-c++-32bit is needed to build 32bit code (boo#1101338).
* Mon Feb  5 2018 mvetter@suse.com
- Update to version 9
  * Simplify away redundant SEE pruning condition
  * Limit the king distance factor when evaluating passed pawns
  * Simplify verification search
  * Many other improvements
* Sun Nov 20 2016 rpm@fthiessen.de
- Fixed architecture detection in spec file.
* Fri Nov  4 2016 mvetter@suse.com
- Update to version 8
* Mon Jun 13 2016 psimons@suse.com
- Install license file as part of the documentation.
* Fri Jun  3 2016 psimons@suse.com
- Drop Stockfish-CMakeLists.txt and stockfish-polyglot.ini. These
  files aren't necessary for building (or running) Stockfish.
* Thu Apr 28 2016 mvetter@suse.com
- Update to version 7
- Added date.patch: Get rid of __DATE__
* Tue Sep  1 2015 mvetter@suse.com
- Initial package for version 6
